================
Citing AstroPhot
================

If you use AstroPhot for a project that leads to a publication, whether directly
or as a dependency of another package, please include a citation to the
`AstroPhot paper <https://doi.org/10.1093/mnras/stad2477>`_

Bibtex::

  @ARTICLE{Stone2023,
         author = {{Stone}, Connor J. and {Courteau}, St{\'e}phane and {Cuillandre}, Jean-Charles and {Hezaveh}, Yashar and {Perreault-Levasseur}, Laurence and {Arora}, Nikhil},
          title = "{AstroPhot: Fitting Everything Everywhere All at Once in Astronomical Images}",
        journal = {\mnras},
       keywords = {galaxies: general, galaxies: photometry, stars: imaging, software: data analysis, techniques: image processing, techniques: photometric, Astrophysics - Instrumentation and Methods for Astrophysics, Astrophysics - Astrophysics of Galaxies, Astrophysics - Solar and Stellar Astrophysics},
           year = 2023,
          month = aug,
            doi = {10.1093/mnras/stad2477},
  archivePrefix = {arXiv},
         eprint = {2308.01957},
   primaryClass = {astro-ph.IM},
         adsurl = {https://ui.adsabs.harvard.edu/abs/2023MNRAS.tmp.2330S},
        adsnote = {Provided by the SAO/NASA Astrophysics Data System}
  }

If you would like to identify the exact version of AstroPhot that you used in
your analysis, please then also include a citation for the GitHub repository at
the relevant version number from the `home page
<https://github.com/Autostronomy/AstroPhot>`_.
